summaryrefslogtreecommitdiffstats
path: root/sipgen/sip.h
diff options
context:
space:
mode:
Diffstat (limited to 'sipgen/sip.h')
-rw-r--r--sipgen/sip.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/sipgen/sip.h b/sipgen/sip.h
index 624a1ee..10076a6 100644
--- a/sipgen/sip.h
+++ b/sipgen/sip.h
@@ -44,7 +44,7 @@
/* For convenience. */
#define classBaseName(cd) scopedNameTail((cd)->iff->fqcname)
-#define classFQCName(cd) ((cd)->iff->fqcname)
+#define classFTQCName(cd) ((cd)->iff->fqcname)
/* Handle module flags. */
@@ -90,10 +90,10 @@
#define CLASS_IS_EXTERNAL 0x00080000 /* It is external. */
#define CLASS_IS_DELAYED_DTOR 0x00100000 /* The dtor is delayed. */
#define CLASS_NO_DEFAULT_CTORS 0x00200000 /* Don't create default ctors. */
-#define CLASS_QOBJECT_SUB 0x00400000 /* It is derived from QObject. */
+#define CLASS_TQOBJECT_SUB 0x00400000 /* It is derived from TQObject. */
#define CLASS_DTOR_HOLD_GIL 0x00800000 /* The dtor holds the GIL. */
#define CLASS_ASSIGN_HELPER 0x01000000 /* Generate an assignment helper. */
-#define CLASS_NO_QMETAOBJECT 0x02000000 /* It has no QMetaObject. */
+#define CLASS_NO_TQMETAOBJECT 0x02000000 /* It has no TQMetaObject. */
#define CLASS_IS_TEMPLATE 0x04000000 /* It is a template class. */
#define CLASS_IS_DEPRECATED 0x08000000 /* It is deprecated. */
#define CLASS_CANNOT_COPY 0x10000000 /* It cannot be copied. */
@@ -130,14 +130,14 @@
#define setIsDelayedDtor(cd) ((cd)->classflags |= CLASS_IS_DELAYED_DTOR)
#define noDefaultCtors(cd) ((cd)->classflags & CLASS_NO_DEFAULT_CTORS)
#define setNoDefaultCtors(cd) ((cd)->classflags |= CLASS_NO_DEFAULT_CTORS)
-#define isQObjectSubClass(cd) ((cd)->classflags & CLASS_QOBJECT_SUB)
-#define setIsQObjectSubClass(cd) ((cd)->classflags |= CLASS_QOBJECT_SUB)
+#define isTQObjectSubClass(cd) ((cd)->classflags & CLASS_TQOBJECT_SUB)
+#define setIsTQObjectSubClass(cd) ((cd)->classflags |= CLASS_TQOBJECT_SUB)
#define isHoldGILDtor(cd) ((cd)->classflags & CLASS_DTOR_HOLD_GIL)
#define setIsHoldGILDtor(cd) ((cd)->classflags |= CLASS_DTOR_HOLD_GIL)
#define assignmentHelper(cd) ((cd)->classflags & CLASS_ASSIGN_HELPER)
#define setAssignmentHelper(cd) ((cd)->classflags |= CLASS_ASSIGN_HELPER)
-#define noPyQt4QMetaObject(cd) ((cd)->classflags & CLASS_NO_QMETAOBJECT)
-#define setPyQt4NoQMetaObject(cd) ((cd)->classflags |= CLASS_NO_QMETAOBJECT)
+#define noPyTQt4TQMetaObject(cd) ((cd)->classflags & CLASS_NO_TQMETAOBJECT)
+#define setPyTQt4NoTQMetaObject(cd) ((cd)->classflags |= CLASS_NO_TQMETAOBJECT)
#define isTemplateClass(cd) ((cd)->classflags & CLASS_IS_TEMPLATE)
#define setIsTemplateClass(cd) ((cd)->classflags |= CLASS_IS_TEMPLATE)
#define resetIsTemplateClass(cd) ((cd)->classflags &= ~CLASS_IS_TEMPLATE)
@@ -425,7 +425,7 @@
typedef enum {
str_slot,
- unicode_slot,
+ tqunicode_slot,
int_slot,
long_slot,
float_slot,
@@ -722,7 +722,7 @@ typedef struct _moduleDef {
apiVersionRangeDef *api_versions; /* The defined APIs. */
apiVersionRangeDef *api_ranges; /* The list of API version ranges. */
int modflags; /* The module flags. */
- int qobjclass; /* QObject class, -1 if none. */
+ int qobjclass; /* TQObject class, -1 if none. */
struct _memberDef *othfuncs; /* List of other functions. */
struct _overDef *overs; /* Global overloads. */
argType encoding; /* The default string encoding. */
@@ -988,7 +988,7 @@ typedef struct _mroDef {
typedef struct _classDef {
int classflags; /* The class flags. */
- int pyqt4_flags; /* The PyQt4 specific flags. */
+ int pyqt4_flags; /* The PyTQt4 specific flags. */
nameDef *pyname; /* The Python name. */
ifaceFileDef *iff; /* The interface file. */
struct _classDef *ecd; /* The enclosing scope. */
@@ -1138,8 +1138,8 @@ codeBlock *templateCode(sipSpec *pt, ifaceFileList **used, codeBlock *ocb, scope
ifaceFileDef *findIfaceFile(sipSpec *pt, moduleDef *mod,
scopedNameDef *fqname, ifaceFileType iftype,
apiVersionRangeDef *api_range, argDef *ad);
-int pluginPyQt3(sipSpec *pt);
-int pluginPyQt4(sipSpec *pt);
+int pluginPyTQt3(sipSpec *pt);
+int pluginPyTQt4(sipSpec *pt);
void yywarning(char *);
nameDef *cacheName(sipSpec *pt, const char *name);
scopedNameDef *encodedTemplateName(templateDef *td);